def calculate_roi(initial: int, final: int):
    return(final - initial)/ initial

def project_growth(initial, growth_rate, years):
    return initial * (1 + growth_rate) ** years

#underscore before a variable name means for developers not to mess with the variable. That is, it's kinda a secret variable
_my_secret_variable = 58


from setuptools import setup, find_packages

#command to run to install package: "pip install -e . "

setup(
    name='introtopython-okechio-finance-tools',
    version='0.1.0',
    packages=find_packages("."),
    install_requires=[
        'numpy',
        'pandas'
    ],
    author='Okechi Osuagwu',
    description="""
    A collection of tools for finacial analysis
    """,
    license='MIT'
)


#This import will fail
#from analytics.metrics import volatility 

#To fix the import issue
import sys
import os
sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))

from analytics.metrics import volatility # Now it works

def risk_assessment(investment, volatility):
    return investment * volatility
